==> xlniuxdata_gamepay_new-1.3.8-sources.jar: com/xunlei/gamepay/vo/PayDetailOK.java <==
package com.xunlei.gamepay.vo;

import com.xunlei.common.util.Extendable;

public class PayDetailOK {


	private long seqid;
	private String gameid;
	private String paybizno;
	private String chargetype;
	private String bankno;
	private String chargebizno;
	private String fromusername;
	private String frominneruserid;
	private String tousername;
	private String toinneruserid;
	private String serverid;
	private String servername;
	private String roleid;
	private String rolename;
	private String unitprice;
	private String goodstimes;
	private String totalmoney;
	private String orderid;
	private String ordertime;
	private String orderidstatus;
	private String paycode;
	private String successtime;
	private String editby;
	private String edittime;
	private String ip;
	private String chargeSuccessTime;
	private String giftFlag;
	private String computeIncomeFlag;
	private String originalOrderid;
	private String copartnerid;
	private String niuxactno; //活动编号	
	private String noticeActivity;
	private String extparam;
	private Double payMondey;//支付总金额
	private Double vouchersMoney;//代金券金额
	private String vouchers;//代金券编号
	private String noticeVip;
	private String gameext;//游戏扩展参数，主要用于手游充值	

	@Extendable
	private String epayMondey;
	@Extendable
	private String evouchers;
	
	@Extendable
	private String copartnerOrderId;
	
	private String referfrom;
	@Extendable
	private String fromOrderTime;
	@Extendable
	private String toOrderTime;
	
	@Extendable
	private String fromSuccessTme;
	@Extendable
	private String toSuccessTime;
	
	@Extendable
	private String dsname;
	
	@Extendable
	private String excepttest;
	public String getExcepttest() {
		return excepttest;
	}
	public void setExcepttest(String excepttest) {
		this.excepttest = excepttest;
	}
	
	
	@Extendable
	private String gifttype;
	
	public String getGifttype() {
		return gifttype;
	}
	public void setGifttype(String gifttype) {
		this.gifttype = gifttype;
	}
	public String getDsname() {
		return dsname;
	}
	public void setDsname(String dsname) {
		this.dsname = dsname;
	}	
	public String getGameext() {
		return gameext;
	}
	public void setGameext(String gameext) {
		this.gameext = gameext;
	}
	public String getNoticeVip() {
		return noticeVip;
	}
	public void setNoticeVip(String noticeVip) {
		this.noticeVip = noticeVip;
	}
	public long getSeqid() {
		return seqid;
	}
	public void setSeqid(long seqid) {
		this.seqid = seqid;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public String getPaybizno() {
		return paybizno;
	}
	public void setPaybizno(String paybizno) {
		this.paybizno = paybizno;
	}
	public String getChargetype() {
		return chargetype;
	}
	public void setChargetype(String chargetype) {
		this.chargetype = chargetype;
	}
	public String getBankno() {
		return bankno;
	}
	public void setBankno(String bankno) {
		this.bankno = bankno;
	}
	public String getChargebizno() {
		return chargebizno;
	}
	public void setChargebizno(String chargebizno) {
		this.chargebizno = chargebizno;
	}
	public String getFromusername() {
		return fromusername;
	}
	public void setFromusername(String fromusername) {
		this.fromusername = fromusername;
	}
	public String getFrominneruserid() {
		return frominneruserid;
	}
	public void setFrominneruserid(String frominneruserid) {
		this.frominneruserid = frominneruserid;
	}
	public String getTousername() {
		return tousername;
	}
	public void setTousername(String tousername) {
		this.tousername = tousername;
	}
	public String getToinneruserid() {
		return toinneruserid;
	}
	public void setToinneruserid(String toinneruserid) {
		this.toinneruserid = toinneruserid;
	}
	public String getServerid() {
		return serverid;
	}
	public void setServerid(String serverid) {
		this.serverid = serverid;
	}
	public String getServername() {
		return servername;
	}
	public void setServername(String servername) {
		this.servername = servername;
	}
	public String getRoleid() {
		return roleid;
	}
	public void setRoleid(String roleid) {
		this.roleid = roleid;
	}
	public String getRolename() {
		return rolename;
	}
	public void setRolename(String rolename) {
		this.rolename = rolename;
	}
	public String getUnitprice() {
		return unitprice;
	}
	public void setUnitprice(String unitprice) {
		this.unitprice = unitprice;
	}
	public String getGoodstimes() {
		return goodstimes;
	}
	public void setGoodstimes(String goodstimes) {
		this.goodstimes = goodstimes;
	}
	public String getTotalmoney() {
		return totalmoney;
	}
	public void setTotalmoney(String totalmoney) {
		this.totalmoney = totalmoney;
	}
	public String getOrderid() {
		return orderid;
	}
	public void setOrderid(String orderid) {
		this.orderid = orderid;
	}
	public String getOrdertime() {
		return ordertime;
	}
	public void setOrdertime(String ordertime) {
		this.ordertime = ordertime;
	}
	public String getOrderidstatus() {
		return orderidstatus;
	}
	public void setOrderidstatus(String orderidstatus) {
		this.orderidstatus = orderidstatus;
	}
	public String getPaycode() {
		return paycode;
	}
	public void setPaycode(String paycode) {
		this.paycode = paycode;
	}
	public String getSuccesstime() {
		return successtime;
	}
	public void setSuccesstime(String successtime) {
		this.successtime = successtime;
	}
	public String getEditby() {
		return editby;
	}
	public void setEditby(String editby) {
		this.editby = editby;
	}
	public String getEdittime() {
		return edittime;
	}
	public void setEdittime(String edittime) {
		this.edittime = edittime;
	}
	public String getIp() {
		return ip;
	}
	public void setIp(String ip) {
		this.ip = ip;
	}
	public String getChargeSuccessTime() {
		return chargeSuccessTime;
	}
	public void setChargeSuccessTime(String chargeSuccessTime) {
		this.chargeSuccessTime = chargeSuccessTime;
	}
	public String getGiftFlag() {
		return giftFlag;
	}
	public void setGiftFlag(String giftFlag) {
		this.giftFlag = giftFlag;
	}
	public String getComputeIncomeFlag() {
		return computeIncomeFlag;
	}
	public void setComputeIncomeFlag(String computeIncomeFlag) {
		this.computeIncomeFlag = computeIncomeFlag;
	}
	public String getOriginalOrderid() {
		return originalOrderid;
	}
	public void setOriginalOrderid(String originalOrderid) {
		this.originalOrderid = originalOrderid;
	}
	public String getCopartnerid() {
		return copartnerid;
	}
	public void setCopartnerid(String copartnerid) {
		this.copartnerid = copartnerid;
	}
	public String getCopartnerOrderId() {
		return copartnerOrderId;
	}
	public void setCopartnerOrderId(String copartnerOrderId) {
		this.copartnerOrderId = copartnerOrderId;
	}
	public String getReferfrom() {
		return referfrom;
	}
	public void setReferfrom(String referfrom) {
		this.referfrom = referfrom;
	}
	public String getFromOrderTime() {
		return fromOrderTime;
	}
	public void setFromOrderTime(String fromOrderTime) {
		this.fromOrderTime = fromOrderTime;
	}
	public String getToOrderTime() {
		return toOrderTime;
	}
	public void setToOrderTime(String toOrderTime) {
		this.toOrderTime = toOrderTime;
	}
	public Double getVouchersMoney() {
		return vouchersMoney;
	}
	public void setVouchersMoney(Double vouchersMoney) {
		this.vouchersMoney = vouchersMoney;
	}
	public String getVouchers() {
		return vouchers;
	}
	public void setVouchers(String vouchers) {
		this.vouchers = vouchers;
	}
	
	public Double getPayMondey() {
		return payMondey;
	}
	public void setPayMondey(Double payMondey) {
		this.payMondey = payMondey;
	}
	public String getNiuxactno() {
		return niuxactno;
	}
	public void setNiuxactno(String niuxactno) {
		this.niuxactno = niuxactno;
	}
	public String getEpayMondey() {
		return epayMondey;
	}
	public void setEpayMondey(String epayMondey) {
		this.epayMondey = epayMondey;
	}
	public String getEvouchers() {
		return evouchers;
	}
	public void setEvouchers(String evouchers) {
		this.evouchers = evouchers;
	}
	public String getNoticeActivity() {
		return noticeActivity;
	}
	public void setNoticeActivity(String noticeActivity) {
		this.noticeActivity = noticeActivity;
	}
	public String getExtparam() {
		return extparam;
	}
	public void setExtparam(String extparam) {
		this.extparam = extparam;
	}
	public String getFromSuccessTme() {
		return fromSuccessTme;
	}
	public void setFromSuccessTme(String fromSuccessTme) {
		this.fromSuccessTme = fromSuccessTme;
	}
	public String getToSuccessTime() {
		return toSuccessTime;
	}
	public void setToSuccessTime(String toSuccessTime) {
		this.toSuccessTime = toSuccessTime;
	}
}

==> xlniuxdata_gamepay_new-1.4.13-sources.jar: com/xunlei/gamepay/vo/PayDetailOK.java <==
package com.xunlei.gamepay.vo;

import com.xunlei.common.util.Extendable;

public class PayDetailOK {


	private long seqid;
	private String gameid;
	private String paybizno;
	private String chargetype;
	private String bankno;
	private String chargebizno;
	private String fromusername;
	private String frominneruserid;
	private String tousername;
	private String toinneruserid;
	private String serverid;
	private String servername;
	private String roleid;
	private String rolename;
	private String unitprice;
	private String goodstimes;
	private String totalmoney;
	private String orderid;
	private String ordertime;
	private String orderidstatus;
	private String paycode;
	private String successtime;
	private String editby;
	private String edittime;
	private String ip;
	private String chargeSuccessTime;
	private String giftFlag;
	private String computeIncomeFlag;
	private String originalOrderid;
	private String copartnerid;
	private String niuxactno; //活动编号	
	private String noticeActivity;
	private String extparam;
	private Double payMondey;//支付总金额
	private Double vouchersMoney;//代金券金额
	private String vouchers;//代金券编号
	private String noticeVip;
	private String gameext;//游戏扩展参数，主要用于手游充值	

	@Extendable
	private String epayMondey;
	@Extendable
	private String evouchers;
	
	@Extendable
	private String copartnerOrderId;
	
	private String referfrom;
	@Extendable
	private String fromOrderTime;
	@Extendable
	private String toOrderTime;
	
	@Extendable
	private String fromSuccessTme;
	@Extendable
	private String toSuccessTime;
	
	@Extendable
	private String dsname;
	
	@Extendable
	private String excepttest;
	public String getExcepttest() {
		return excepttest;
	}
	public void setExcepttest(String excepttest) {
		this.excepttest = excepttest;
	}
	
	
	@Extendable
	private String gifttype;
	
	@Extendable
	private String customerid;
	
	public String getCustomerid() {
		return customerid;
	}
	public void setCustomerid(String customerid) {
		this.customerid = customerid;
	}
	public String getGifttype() {
		return gifttype;
	}
	public void setGifttype(String gifttype) {
		this.gifttype = gifttype;
	}
	public String getDsname() {
		return dsname;
	}
	public void setDsname(String dsname) {
		this.dsname = dsname;
	}	
	public String getGameext() {
		return gameext;
	}
	public void setGameext(String gameext) {
		this.gameext = gameext;
	}
	public String getNoticeVip() {
		return noticeVip;
	}
	public void setNoticeVip(String noticeVip) {
		this.noticeVip = noticeVip;
	}
	public long getSeqid() {
		return seqid;
	}
	public void setSeqid(long seqid) {
		this.seqid = seqid;
	}
	public String getGameid() {
		return gameid;
	}
	public void setGameid(String gameid) {
		this.gameid = gameid;
	}
	public String getPaybizno() {
		return paybizno;
	}
	public void setPaybizno(String paybizno) {
		this.paybizno = paybizno;
	}
	public String getChargetype() {
		return chargetype;
	}
	public void setChargetype(String chargetype) {
		this.chargetype = chargetype;
	}
	public String getBankno() {
		return bankno;
	}
	public void setBankno(String bankno) {
		this.bankno = bankno;
	}
	public String getChargebizno() {
		return chargebizno;
	}
	public void setChargebizno(String chargebizno) {
		this.chargebizno = chargebizno;
	}
	public String getFromusername() {
		return fromusername;
	}
	public void setFromusername(String fromusername) {
		this.fromusername = fromusername;
	}
	public String getFrominneruserid() {
		return frominneruserid;
	}
	public void setFrominneruserid(String frominneruserid) {
		this.frominneruserid = frominneruserid;
	}
	public String getTousername() {
		return tousername;
	}
	public void setTousername(String tousername) {
		this.tousername = tousername;
	}
	public String getToinneruserid() {
		return toinneruserid;
	}
	public void setToinneruserid(String toinneruserid) {
		this.toinneruserid = toinneruserid;
	}
	public String getServerid() {
		return serverid;
	}
	public void setServerid(String serverid) {
		this.serverid = serverid;
	}
	public String getServername() {
		return servername;
	}
	public void setServername(String servername) {
		this.servername = servername;
	}
	public String getRoleid() {
		return roleid;
	}
	public void setRoleid(String roleid) {
		this.roleid = roleid;
	}
	public String getRolename() {
		return rolename;
	}
	public void setRolename(String rolename) {
		this.rolename = rolename;
	}
	public String getUnitprice() {
		return unitprice;
	}
	public void setUnitprice(String unitprice) {
		this.unitprice = unitprice;
	}
	public String getGoodstimes() {
		return goodstimes;
	}
	public void setGoodstimes(String goodstimes) {
		this.goodstimes = goodstimes;
	}
	public String getTotalmoney() {
		return totalmoney;
	}
	public void setTotalmoney(String totalmoney) {
		this.totalmoney = totalmoney;
	}
	public String getOrderid() {
		return orderid;
	}
	public void setOrderid(String orderid) {
		this.orderid = orderid;
	}
	public String getOrdertime() {
		return ordertime;
	}
	public void setOrdertime(String ordertime) {
		this.ordertime = ordertime;
	}
	public String getOrderidstatus() {
		return orderidstatus;
	}
	public void setOrderidstatus(String orderidstatus) {
		this.orderidstatus = orderidstatus;
	}
	public String getPaycode() {
		return paycode;
	}
	public void setPaycode(String paycode) {
		this.paycode = paycode;
	}
	public String getSuccesstime() {
		return successtime;
	}
	public void setSuccesstime(String successtime) {
		this.successtime = successtime;
	}
	public String getEditby() {
		return editby;
	}
	public void setEditby(String editby) {
		this.editby = editby;
	}
	public String getEdittime() {
		return edittime;
	}
	public void setEdittime(String edittime) {
		this.edittime = edittime;
	}
	public String getIp() {
		return ip;
	}
	public void setIp(String ip) {
		this.ip = ip;
	}
	public String getChargeSuccessTime() {
		return chargeSuccessTime;
	}
	public void setChargeSuccessTime(String chargeSuccessTime) {
		this.chargeSuccessTime = chargeSuccessTime;
	}
	public String getGiftFlag() {
		return giftFlag;
	}
	public void setGiftFlag(String giftFlag) {
		this.giftFlag = giftFlag;
	}
	public String getComputeIncomeFlag() {
		return computeIncomeFlag;
	}
	public void setComputeIncomeFlag(String computeIncomeFlag) {
		this.computeIncomeFlag = computeIncomeFlag;
	}
	public String getOriginalOrderid() {
		return originalOrderid;
	}
	public void setOriginalOrderid(String originalOrderid) {
		this.originalOrderid = originalOrderid;
	}
	public String getCopartnerid() {
		return copartnerid;
	}
	public void setCopartnerid(String copartnerid) {
		this.copartnerid = copartnerid;
	}
	public String getCopartnerOrderId() {
		return copartnerOrderId;
	}
	public void setCopartnerOrderId(String copartnerOrderId) {
		this.copartnerOrderId = copartnerOrderId;
	}
	public String getReferfrom() {
		return referfrom;
	}
	public void setReferfrom(String referfrom) {
		this.referfrom = referfrom;
	}
	public String getFromOrderTime() {
		return fromOrderTime;
	}
	public void setFromOrderTime(String fromOrderTime) {
		this.fromOrderTime = fromOrderTime;
	}
	public String getToOrderTime() {
		return toOrderTime;
	}
	public void setToOrderTime(String toOrderTime) {
		this.toOrderTime = toOrderTime;
	}
	public Double getVouchersMoney() {
		return vouchersMoney;
	}
	public void setVouchersMoney(Double vouchersMoney) {
		this.vouchersMoney = vouchersMoney;
	}
	public String getVouchers() {
		return vouchers;
	}
	public void setVouchers(String vouchers) {
		this.vouchers = vouchers;
	}
	
	public Double getPayMondey() {
		return payMondey;
	}
	public void setPayMondey(Double payMondey) {
		this.payMondey = payMondey;
	}
	public String getNiuxactno() {
		return niuxactno;
	}
	public void setNiuxactno(String niuxactno) {
		this.niuxactno = niuxactno;
	}
	public String getEpayMondey() {
		return epayMondey;
	}
	public void setEpayMondey(String epayMondey) {
		this.epayMondey = epayMondey;
	}
	public String getEvouchers() {
		return evouchers;
	}
	public void setEvouchers(String evouchers) {
		this.evouchers = evouchers;
	}
	public String getNoticeActivity() {
		return noticeActivity;
	}
	public void setNoticeActivity(String noticeActivity) {
		this.noticeActivity = noticeActivity;
	}
	public String getExtparam() {
		return extparam;
	}
	public void setExtparam(String extparam) {
		this.extparam = extparam;
	}
	public String getFromSuccessTme() {
		return fromSuccessTme;
	}
	public void setFromSuccessTme(String fromSuccessTme) {
		this.fromSuccessTme = fromSuccessTme;
	}
	public String getToSuccessTime() {
		return toSuccessTime;
	}
	public void setToSuccessTime(String toSuccessTime) {
		this.toSuccessTime = toSuccessTime;
	}
}
